@@ -38,7 +38,7 @@ our(@ISA, $VERSION);
 BEGIN {
     @ISA = qw(PAR::Filter);
 
-    $VERSION = '1.08';
+    $VERSION = '2.07';
 }
 
 #===============================================================================
@@ -55,7 +55,7 @@ sub apply {
     # encrypt the decryption module.
     return 1 if $filename eq 'Filter/Crypto/Decrypt.pm';
 
-    if (eval { require Module::ScanDeps; 1 } and
+    if (eval { require Module::ScanDeps } and
         $Module::ScanDeps::VERSION eq '0.75')
     {
         carp('Detected Module::ScanDeps version 0.75, which may not work ' .
@@ -263,11 +263,11 @@ License or the Artistic License, as specified in the F<LICENCE> file.
 
 =head1 VERSION
 
-Version 1.08
+Version 2.07
 
 =head1 DATE
 
-16 May 2014
+28 Feb 2015
 
 =head1 HISTORY
 
